@@ -341,6 +341,6 @@ class FocusVisionCreator(SurveyCreator):
             data=self.survey_data,
             questions=self.questions,
             respondents=self.respondents,
-            items=self.respondent_attributes,
+            attributes=self.respondent_attributes,
             groups=groups
         )
